.. documentation master file, created by sphinx-quickstart on Mon Nov 30 18:51:11 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Table of contents
=================

.. toctree::
   :maxdepth: 2

   intro
   cli
   changelogs

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

